PRO alb


;*************************************************************************
; Name: alb
;
; Purpose:
;   This rountine is the main driver to plot granule level surface albedos.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's albedo map, generated in
;    the albedo mapping routine, and produces albedo images for 6 spectral
;    bands.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the albedo map stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_alb.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************

;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names. 
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')
jday = fix(day)

;*************************************************************************
; Define the file that contains the albedo information.
;*************************************************************************
stjday = Strcompress(string(jday),/REMOVE_ALL)
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filen = temp_HDF_path + 'GranAlbMap.'+year+'.'+day+'.'+time+'.hdf'
filenames = [filen]


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the Ancillary SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 6
PlotAnci    = IntArr(numSDS)
PlotAnci[0] = 1 ; band 1 = 0.659 um 
PlotAnci[1] = 1 ; band 2 = 0.858 um
PlotAnci[2] = 1 ; band 3 = 1.24 um 
PlotAnci[3] = 1 ; band 4 = 1.64 um 
PlotAnci[4] = 1 ; band 5 = 2.13 um 
PlotAnci[5] = 1 ; band 6 = 3.74 um 

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
AnciOutName    = StrArr(numSDS)
;MOD06 SDSs:
AnciOutName[0] = '0.659'
AnciOutName[1] = '0.858'
AnciOutName[2] = '1.24'
AnciOutName[3] = '1.64'
AnciOutName[4] = '2.13'
AnciOutName[5] = '3.74'


;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
TitleName    = StrArr(numSDS)
;MOD06 SDSs:
TitleName[0] = 'White Sky Albedo, MODIS band 1, 0.659 um'
TitleName[1] = 'White Sky Albedo, MODIS band 2, 0.858 um'
TitleName[2] = 'White Sky Albedo, MODIS band 5, 1.24 um'
TitleName[3] = 'White Sky Albedo, MODIS band 6, 1.64 um'
TitleName[4] = 'White Sky Albedo, MODIS band 7, 2.13 um'
TitleName[5] = 'White Sky Albedo, MODIS band 20, 3.74 um'


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
AnciSDSLimits      = FltArr(numSDS,2)
;MOD06 SDSs:
AnciSDSLimits[0,0] = 0.0 ;band 0, min
AnciSDSLimits[0,1] = 0.5 ;band 0, max
AnciSDSLimits[1,0] = 0.0 ;band 1, min
AnciSDSLimits[1,1] = 0.5 ;band 1, max
AnciSDSLimits[2,0] = 0.0 ;band 2, min
AnciSDSLimits[2,1] = 0.5 ;band 2, max
AnciSDSLimits[3,0] = 0.0 ;band 3, min
AnciSDSLimits[3,1] = 0.5 ;band 3, max
AnciSDSLimits[4,0] = 0.0 ;band 4, min
AnciSDSLimits[4,1] = 0.5 ;band 5, max
AnciSDSLimits[5,0] = 0.0 ;band 6, min
AnciSDSLimits[5,1] = 0.5 ;band 6, max


;*************************************************************************
; Choose the number of levels to be included on the color bar:
;*************************************************************************
Num_CB_Levels    = IntArr(numSDS)
Num_CB_Levels[0] = 5 ; band 0
Num_CB_Levels[1] = 5 ; band 1
Num_CB_Levels[2] = 5 ; band 2
Num_CB_Levels[3] = 5 ; band 3
Num_CB_Levels[4] = 5 ; band 4
Num_CB_Levels[5] = 5 ; band 5



;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits      = StrArr(numSDS)
;MOD06 SDSs:
SDSunits[0]   = 'no units'
SDSunits[1]   = 'no units'
SDSunits[2]   = 'no units'
SDSunits[3]   = 'no units'
SDSunits[4]   = 'no units'
SDSunits[5]   = 'no units'


;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file.
;*************************************************************************
AnciSDSName    = StrArr(numSDS)
;MOD06 SDSs:
AnciSDSName[0] = 'Albedo_Map'
AnciSDSName[1] = 'Albedo_Map'
AnciSDSName[2] = 'Albedo_Map'
AnciSDSName[3] = 'Albedo_Map'
AnciSDSName[4] = 'Albedo_Map'
AnciSDSName[5] = 'Albedo_Map'



;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;*************************************************************************
MDchoice    = IntArr(numSDS)
;MOD06 SDSs:
MDchoice[0] = 0
MDchoice[1] = 1
MDchoice[2] = 2
MDchoice[3] = 3
MDchoice[4] = 4
MDchoice[5] = 5





;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-1 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   AnciOutFileName = output_dir+'Albedo.'+year+'.'+day+'.'+time+'.'+AnciOutName[icnt]+'.ps'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = TitleName[icnt]+'.  Time '+time+' Julian Day '+stjday+' '+year+'.'

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits=0
   ;*************************************************************************
   limits=0

   ;*************************************************************************
   ;Call the program, bearing in mind that only the postscript output is 
   ; available.  The basic call is as follows:
   ;*************************************************************************
   ;Since these are two dim, set multidim_choice to 0:
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (PlotAnci[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',AnciSDSName[icnt]
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      plot_alb, filenames, AnciSDSName[icnt],       $
                AnciOutFileName, SDS_limits, limits,$
                titlestring, multidim_choice,       $
                Num_CB_Levels[icnt],                $
                /ps, /notation
   ENDIF ELSE BEGIN
      print, 'Skipping ',AnciSDSName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


END
