function createalbedo, jday, lat_arr, EcoType_arr

;..............................................................................
; $Id: GetAlbedo.f90,v 1.0 2001/04/25 11:18:08 EGMoody Exp EGMoody $
;..............................................................................
;F90
;
;DESCRIPTION:
;      Returns white sky albedos for a given ecosystem type map, at six wavelengths
;      of interest (0.659, 0.865, 1.240, 1.640, 2.130, 3.7 microns).  Seasonal
;      effects are considered for northern (> 20 degrees) and southern (< -20
;      degrees) hemispheres, based on the julian date, and pixel latitude.  The
;      tropical zone ( between +- 20 degrees) is considered constant, with a 
;      transition zone (between +-20 - +-30) used for smoothing the discontinuity
;      between tropical and hemisphere zones.
;
;INPUT PARAMETERS:
;
;      jday    = julian day
;      lat     = pixel latitude
;      ecoType = pixel scene type
;      
;
;OUTPUT PARAMETERS: 
;
;      albedo = spectral albedo
;
;!!!!!!!!!!!!!!!!!!!!!! I M P O R T A N T  N O T E S !!!!!!!!!!!!!!!!!!!!!!!!!!
;
;      	Representative white sky albedos for each ecosystem type, 1-17, were 
;       obtained using by using MOD43B3 global albedo data, in tandem with
;       MOD12Q1 IGBP global ecosystem data.  
;
;		Due to limited amounts of data available for the current delivery 
;       (5/1/2001), a representative set of "winter" albedos where obtained 
;		by binning by ecosystem type, in the northern hemisphere (>20 degrees), 
; 		using jday 305, year 2000, MOD43B3 data.  The "summer" albedoes where
; 		obtained using southern hemisphere (< -20 degrees) data from jday 321,
; 		year 2000.  The tropical ( between +- 20) values were obtained from
;		jday 321, year 2000.  The binning was performed using MOD12Q1 ecosystem
;		data from jday 289, year 2000.
;
;		The seasonal effects are created by using a sinusoidal fit of the "winter"
; 		and "summer" data, by assuming that these values represent albedos at
; 		the summer and winter solstices, where it is assumed that the albedos
;		are at their respective extremes.
;
;		There are five latitude belts considered for this albedo "map", northern
;       hemisphere (>30), southern hemisphere (<-30), the tropics (between +-20),
;		and two transition regions (20 to 30, and -30 to -20).  The northern and
;		summer hemispheres have the seasonal variation defined above, the tropics
;		have constant albedos, and the transition regions smooth the discontinuity
;		between the tropics and the hemispheres by using a linear fit of the
; 		tropic's albedo and the hemisphere's albedo value.
;       
;
;..............................................................................
;REVISION HISTORY:
; $Log$
;..............................................................................
;TEAM-UNIQUE HEADER:
;             Written by Eric G. Moody
;             eric.moody.gsfc.nasa.gov
;             Climate and Radiation Branch
;             NASA Goddard Space Flight Center
;             Greenbelt, Maryland, U.S.A.
;..............................................................................
;.......................................................................
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;.......................................................................
;..............................................................................
;End

;INTEGER(I4B), INTENT(IN)     :: orig_jday
;REAL   (SP ), INTENT(IN)     :: lat
;INTEGER(I1B), INTENT(IN)     :: ecoType
;REAL   (SP ), DIMENSION(:)   :: albedo

;  	orig_jday	:	The julian day that is passed to the subroutine
;	lat			:	The latitude of the pixel
;	ecoType		:   The IGBP ecosystem surface scene type
;	albedo		: 	The white-sky albedo values, for the six wavelengths


;Real(SP), Dimension(3,6,20)            :: albedo_table
; albedo_table   :  Stores the albedo table, from mean values aggregated
;                   from MOD12Q1 ecosystem and MOD43B3 white-sky albedo
;                   values at the relavent bands.  The array is structured
;                   as follows:
;                   3:  Season,
;                               1 = summer 
;                               2 = winter
;                               3 = tropical
;                   6:  Band Wavelength:
;                               1 = 0.645 micron
;                               2 = 0.858 micron
;                               3 = 1.24  micron
;                               4 = 1.64  micron
;                               5 = 2.13  micron
;                               6 = 3.74  micron
;                   20: Ecosystem scene type, defined above.
;
                   
;Generic Counter:
;INTEGER(I4B)        :: i

;3.7 micron fraction of 2.1 micron.
;real(SP), parameter :: fraction_37 = 0.5000
fraction_37 = 0.5000

;Seasonal variation variables:
;integer(I4B)        :: jday
;real(SP)            :: Amplitude, y_offset, summer_solstice, Period
;real(SP), parameter :: pi_value = 3.14159270d0
pi_value = 3.14159270
;real(SP)            :: slope, intercept, alb_Hem
;	jday			:	The julian date, set to 365 if leap year (as an approx.)
;	Amplitude		:	Amplitude of the sinusoidal fit.
;	y_offset		:	Y offset of the sinusoidal fit.
;	summer_solstice	:	The julian date of the summer solstice.
;	Period			:	Period of the sinusoidal fit.
;	pi_value		: 	The value of Pi.
;	slope			:	The slope of the linear fit.
;	intercept		:	The intercept of the linear fit.
;	alb_Hem			:	Hemisphere's albedo, used in the linear fit.


;... IGBP ecosystem surface scene types:
; ( 1) EVERGREEN NEEDLE FOREST   ( 2) EVERGREEN BROAD  FOREST
; ( 3) DECIDUOUS NEEDLE FOREST   ( 4) DECIDUOUS BROAD  FOREST
; ( 5) MIXED FOREST              ( 6) CLOSED SHRUBS
; ( 7) OPEN/SHRUBS               ( 8) WOODY SAVANNA
; ( 9) SAVANNA                   (10) GRASSLAND
; (11) WETLAND                   (12) CROPLAND
; (13) URBAN                     (14) CROP MOSAIC
; (15) ANTARCTIC SNOW            (16) BARREN/DESERT
; (17) OCEAN WATER               (18) TUNDRA
; (19) FRESH/DRY SNOW            (20) SEA ICE
; (21) PERMINENT ICE		 (22) WET SNOW

;Define the summer albedo values for the ecosystem types:
;     0.659     0.858    1.24     1.64     2.13     3.74 microns
albedo_table_s= REFORM(                                    $
   [ 0.04222, 0.22031, 0.20521, 0.10548, 0.04508, 0.04508, $ ;Evergreen Needle Forest
     0.05603, 0.33227, 0.32429, 0.19531, 0.08681, 0.08681, $ ;Evergreen Broad  Forest
     0.08036, 0.23529, 0.25979, 0.20509, 0.12427, 0.12427, $ ;Deciduous Needle Forest
     0.10243, 0.26507, 0.28033, 0.22043, 0.12955, 0.12955, $ ;Deciduous Broad  Forest
     0.07133, 0.27526, 0.26623, 0.15418, 0.07286, 0.07286, $ ;Mixed Forest
     0.08412, 0.24195, 0.27441, 0.23508, 0.14127, 0.14127, $ ;Closed Shrubland
     0.14669, 0.24542, 0.30695, 0.31364, 0.24182, 0.24182, $ ;Open Shrubland
     0.07045, 0.28070, 0.30356, 0.22453, 0.12145, 0.12145, $ ;Woody Savannas
     0.08328, 0.28865, 0.32313, 0.25405, 0.14490, 0.14490, $ ;Savannas
     0.10992, 0.27952, 0.33016, 0.29120, 0.18843, 0.18843, $ ;Grasslands
     0.07998, 0.20398, 0.20124, 0.14967, 0.08590, 0.08590, $ ;Perm. wetlands
     0.11641, 0.30108, 0.34447, 0.29252, 0.17672, 0.17672, $ ;Croplands
     0.09087, 0.25731, 0.26656, 0.20708, 0.13707, 0.13707, $ ;Urban & built-up
     0.07417, 0.34395, 0.35212, 0.24735, 0.12635, 0.12635, $ ;Cropland mosaics
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Snow/Ice 
     0.34885, 0.41770, 0.48565, 0.52709, 0.50776, 0.25388, $ ;Barren/Sparse Veg
     0.05000, 0.05000, 0.05000, 0.05000, 0.05000, 0.05000, $ ;Water Bodies
     0.10000, 0.25000, 0.30000, 0.25000, 0.15000, 0.05000, $ ;Tundra
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Fresh Snow
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Sea Ice
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Perminant Ice
     0.85000, 0.75000, 0.25000, 0.05000, 0.05000, 0.05000], $ ;Wet Snow
                         6, 22                             )


;Define the winter albedo values for the ecosystem types:
;     0.659     0.858    1.24     1.64     2.13     3.74 microns
albedo_table_w = REFORM(                                   $
   [ 0.04549, 0.17819, 0.17644, 0.10573, 0.05247, 0.05247, $ ;Evergreen Needle Forest
     0.04552, 0.31785, 0.31662, 0.18155, 0.07232, 0.07232, $ ;Evergreen Broad  Forest
     0.09192, 0.18807, 0.19381, 0.13663, 0.08652, 0.08652, $ ;Deciduous Needle Forest
     0.05761, 0.23056, 0.26090, 0.18531, 0.09542, 0.09542, $ ;Deciduous Broad  Forest
     0.05678, 0.19229, 0.21550, 0.15289, 0.08270, 0.08270, $ ;Mixed Forest
     0.08755, 0.21747, 0.25394, 0.20686, 0.13120, 0.13120, $ ;Closed Shrubland
     0.16818, 0.24631, 0.29580, 0.29723, 0.24372, 0.24372, $ ;Open Shrubland
     0.07508, 0.23402, 0.26787, 0.20593, 0.12080, 0.12080, $ ;Woody Savannas
     0.09578, 0.23720, 0.27900, 0.23363, 0.14931, 0.14931, $ ;Savannas
     0.13212, 0.21712, 0.28075, 0.28429, 0.21291, 0.21291, $ ;Grasslands
     0.07509, 0.21504, 0.22970, 0.15472, 0.08098, 0.08098, $ ;Perm. wetlands
     0.09031, 0.22343, 0.26643, 0.23283, 0.15232, 0.15232, $ ;Croplands
     0.09776, 0.21394, 0.23763, 0.20206, 0.13869, 0.13869, $ ;Urban & built-up
     0.07863, 0.25835, 0.29249, 0.22286, 0.12651, 0.12651, $ ;Cropland mosaics
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Snow/Ice
     0.34885, 0.41770, 0.48565, 0.52709, 0.50776, 0.25388, $ ;Barren/Sparse Veg
     0.05000, 0.05000, 0.05000, 0.05000, 0.05000, 0.05000, $ ;Water Bodies
     0.10000, 0.25000, 0.30000, 0.25000, 0.15000, 0.05000, $ ;Tundra
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Fresh Snow
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Sea Ice
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Perminant Ice
     0.85000, 0.75000, 0.25000, 0.05000, 0.05000, 0.05000], $ ;Wet Snow
                         6, 22                              )


;Define the tropical albedo values for the ecosystem types:
;     0.659     0.858    1.24     1.64     2.13     3.74 microns
albedo_table_t = REFORM(                                   $
   [ 0.05999, 0.22086, 0.22479, 0.14854, 0.07236, 0.07236, $ ;Evergreen Needle Forest
     0.06772, 0.34919, 0.34498, 0.19382, 0.08220, 0.08220, $ ;Evergreen Broad  Forest
     0.08141, 0.22551, 0.25907, 0.20851, 0.12899, 0.12899, $ ;Deciduous Needle Forest
     0.10812, 0.28096, 0.34392, 0.28955, 0.18194, 0.18194, $ ;Deciduous Broad  Forest
     0.05836, 0.25317, 0.27197, 0.18123, 0.08823, 0.08823, $ ;Mixed Forest
     0.10439, 0.27004, 0.32049, 0.27573, 0.17893, 0.17893, $ ;Closed Shrubland
     0.18282, 0.29743, 0.36292, 0.35973, 0.28930, 0.28930, $ ;Open Shrubland
     0.07166, 0.28618, 0.31932, 0.22378, 0.11542, 0.11542, $ ;Woody Savannas
     0.09004, 0.27721, 0.32717, 0.26052, 0.15267, 0.15267, $ ;Savannas
     0.12031, 0.26763, 0.33087, 0.29940, 0.20617, 0.20617, $ ;Grasslands
     0.09627, 0.29647, 0.29990, 0.19487, 0.10267, 0.10267, $ ;Perm. wetlands
     0.08767, 0.31173, 0.33267, 0.24248, 0.13566, 0.13566, $ ;Croplands
     0.09662, 0.25265, 0.26485, 0.20728, 0.13839, 0.13839, $ ;Urban & built-up
     0.08569, 0.31492, 0.34767, 0.25772, 0.14099, 0.14099, $ ;Cropland mosaics
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Snow/Ice
     0.34885, 0.41770, 0.48565, 0.52709, 0.50776, 0.25388, $ ;Barren/Sparse Veg
     0.05000, 0.05000, 0.05000, 0.05000, 0.05000, 0.05000, $ ;Water Bodies
     0.10000, 0.25000, 0.30000, 0.25000, 0.15000, 0.05000, $ ;Tundra
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Fresh Snow
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Sea Ice
     0.90000, 0.85000, 0.45000, 0.15000, 0.15000, 0.05000, $ ;Perminant Ice
     0.85000, 0.75000, 0.25000, 0.05000, 0.05000, 0.05000], $ ;Wet Snow
                         6, 22                              )

;Set the 3.7 value to be a fraction of the 2.1 micron values:
for i = 1, 14 do begin
   albedo_table_w(5,i) = albedo_table_w(4,i) * fraction_37
   albedo_table_s(5,i) = albedo_table_s(4,i) * fraction_37
   albedo_table_t(5,i) = albedo_table_t(4,i) * fraction_37
endfor

;Set the Sea Ice to wet or dry snow, depending if it is in the melt season:
;Note that the indexes are from 0:numeco-1
if ( (jday ge 152) and (jday le 244) ) then begin
  ;Melt season, use wet snow values:
  albedo_table_s(*,19) = albedo_table_s(*,21)
  albedo_table_w(*,19) = albedo_table_w(*,21)
  albedo_table_t(*,19) = albedo_table_t(*,21)
endif else begin
  ;Winter, use dry snow values
  albedo_table_s(*,19) = albedo_table_s(*,18)
  albedo_table_w(*,19) = albedo_table_w(*,18)
  albedo_table_t(*,19) = albedo_table_t(*,18)
endelse


;Begin setting the albedos to be returned:
;Determine the size of the map:
dimSizes = size(lat_arr)
xsize = dimSizes(1)
ysize = dimSizes(2)
print , 'x,y sizes', xsize, ysize

;Define the albedo_map
albedo_map = fltarr(xsize,ysize,6)


; Loop over the lat/albedo array:
for xcnt = 0, xsize-1 do begin
    for ycnt = 0, ysize-1 do begin
	
	;Define the pixel's lat and ecotype:
	lat     =     lat_arr(xcnt,ycnt)
	ecotype = ecotype_arr(xcnt,ycnt) - 1
        ; minus 1 since array index is 0 to numpts - 1

;begin the case selection, in substitute of the nested if structure of F90:
CASE 1 OF

;Test to see if this is in the tropics, defined as between +- 20 degrees.
 (lat GE -20.0) and (lat LE 20.0): BEGIN
   albedo = fltarr(6)
   ;This pixel is in the tropics.  In the tropics, we do not have a seasonal 
   ;  variation, so just set the albedo to the cooresponding ecosystem type.
   albedo(*) = albedo_table_t(*,ecotype)

 END

 (lat GT 20.0) and (lat LT 30.0): BEGIN
   ;This pixel is in a transition zone between northern hemisphere and tropical.  To
   ; avoid a sharp discontinuity, a linear fit is used between the northern
   ; hemisphere and tropical albedo values. First the northern hemisphere's albedo
   ; is computed, and then the linear fit is performed.  For details of the northern
   ; hemisphere albedo computation, see the last else section.
   
   ;Define the summer solstice date:
   summer_solstice = 173
   
   ;Define the Period:
   Period = 2.0000 * pi_value / 365.000
   
   ;Loop over the bands, computing the Amplitude, y_offset, hemisphere albedo,
   ;  slope and intercept, and store the computed albedo value.
   albedo = fltarr(6)
   for i = 0, 5 do begin
      
      ;Define the Amplitude:
      Amplitude = (albedo_table_s(i,ecotype) - albedo_table_w(i,ecotype) ) / 2.00

      ;Define the y_offset:
      y_offset = albedo_table_s(i,ecotype) - Amplitude

      ;Store the computed albedo value:
      alb_Hem  = Amplitude * cos( Period * (float(jday) - float(summer_solstice)) ) $
                 + y_offset
      
      ;Compute the slope:
      slope     = ( alb_hem - albedo_table_t(i,ecotype) ) / 10.0

      ;Compute the intercept:
      intercept = 3.0 * albedo_table_t(i,ecotype) - 2.0 * alb_Hem

      ;Compute and store the albedo:
      albedo(i) = slope * lat + intercept

   endfor
 END   

 (lat LT -20.0) and (lat GT -30.0): BEGIN
   ;This pixel is in a transition zone between southern hemisphere and tropical.  To
   ; avoid a sharp discontinuity, a linear fit is used between southern
   ; hemisphere and tropical albedo values. First the southern hemisphere's albedo
   ; is computed, and then the linear fit is performed.  For details of the southern
   ; hemisphere albedo computation, see the last else section.
   
   ;Define the summer solstice date:
   summer_solstice = 356
   
   ;Define the Period:
   Period = 2.0000 * pi_value / 365.000
   
   ;Loop over the bands, computing the Amplitude, y_offset, hemisphere albedo,
   ;  slope and intercept, and store the computed albedo value.
   albedo = fltarr(6)
   for i = 0, 5 do begin
      
      ;Define the Amplitude:
      Amplitude = (albedo_table_s(i,ecotype) - albedo_table_w(i,ecotype) ) / 2.00

      ;Define the y_offset:
      y_offset = albedo_table_s(i,ecotype) - Amplitude

      ;Store the computed albedo value:
      alb_Hem  = Amplitude * cos( Period * (float(jday) - float(summer_solstice)) ) $
                 + y_offset

      ;Compute the slope:
      slope     = ( albedo_table_t(i,ecotype) - alb_Hem ) / 10.0

      ;Compute the intercept:
      intercept = 3.0 * albedo_table_t(i,ecotype) - 2.0 * alb_Hem

      ;Compute and store the albedo:
      albedo(i) = slope * lat + intercept

   endfor
 END
   
 (lat GE 30.0) or (lat LE -30.0): BEGIN
   ;This pixel resides either in the northern or southern hemisphere,
   ; defined as either > 30 or < -30 degrees latitude.  There are representative
   ; values for winter and summer albedo values, and to create a seasonal
   ; variability, a cosine fit will be used.  The fit is based upon the julian
   ; day for the summer solstice (June 22st, day 173, for the Northern Hemisphere,
   ; and December 22nd, day 356, for the Southern Hemisphere).  The form of the fit
   ; is as follows:
   ;   Albedo = Amplitude * cos(Period * (jday - Summer_solstice)) + y_offset
   ; where:
   ;   Period    = 2*pi / number of days in year, number of days in year = 365
   ;   Summer solstice = 172 (NH), or 356 (SH)
   ;   Amplitude = (summer solstice alb val - winter solstice alb val) / 2
   ;   y_offset = summer solstice alb val - Amplitude

   ;Define the Summer solstice date:
   if (lat GE 30.0) then begin
      ;Nothern Hemisphere
      summer_solstice = 173
   endif else begin
      ;Southern Hemisphere
      summer_solstice = 356
   endelse

   ;Define the Period:
   Period = 2.0000 * pi_value / 365.000

   ;Loop over the bands, computing the Amplitude, y_offset, and store the 
   ;  computed albedo value.
   albedo = fltarr(6)
   for i = 0, 5 do begin
      
      ;Define the Amplitude:
      Amplitude = (albedo_table_s(i,ecotype) - albedo_table_w(i,ecotype) ) / 2.00

      ;Define the y_offset:
      y_offset = albedo_table_s(i,ecotype) - Amplitude

      ;Store the computed albedo value:
      albedo(i) = Amplitude *                                             $
                  cos( Period * (float(jday) - float(summer_solstice)) )  $
                  + y_offset

   endfor

 END

ELSE: print, 'Albedo not computed.'
ENDCASE

;Store the albedo in the albedo_map array:
albedo_map(xcnt,ycnt,*) = albedo(*)

;end y and x loop, respectively:
endfor
endfor


; Return the created albedo Map:
return, albedo_map

end

