function createecomap, lat, lon, EcoFileName

;*************************************************************************
; Name: createecomap
;
; Purpose:
;   createEcoMap.pro creates the global ecosystem map which matches a given resolution. 
;   This map is generated by defining the resolution, creating the lat/lon array, and
;   then finding the nearest neighbor from the ecosystem ancillary file, 
;   for each geolocated point.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;    lat                Float Array: Latitude array
;    lon                Float Array: Longitude array
;    EcoFileName        String     : Full path and name of the ecosystem ancillary file
;
; Outputs:
;    ComputedMap        Byte Array : The ecosystem map that matches the geolocation for
;                                       the granule.
;
; Required Programs:
;  Read_Product_sds.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Jason Y. Li
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;Read in the Lat and Lons and Eco Map:
EcoFileID = HDF_SD_START(EcoFileName,/READ)
EcoMap = ReadSDS(EcoFileID,'SceneMap', /scaleNo,/offsetNo,/fillNo)
HDF_SD_END, EcoFileID
dims = size(EcoMap,/dimensions)
EcoXDim = dims(0)
EcoYDim = dims(1)
print, 'Eco X,Y',EcoXDim, EcoYDim

help, EcoMap


;Determine the size of the surface map to be generated:
dims = size(lon,/dimensions)
xdim = dims(0)
ydim = dims(1)
print, 'x,y',xdim,ydim

ComputedMap = bytarr(xdim,ydim)
help, ComputedMap

;find the closest IGBP grid point:
;This Number of Pixels per degree corresponds to the IGBP resolution.
NumPixPerDeg = 60.0
for j = 0, ydim-1 do begin
    for i = 0, xdim-1 do begin

	m = fix((lon(i,j) + 180.0) * NumPixPerDeg - 0.50)
	n = fix((lat(i,j) + 90.0 ) * NumPixPerDeg - 0.50)

        if (lon(i,j) lt -900.) OR (lat(i,j) lt -900.) then begin
           m = 0
           n = 0
        endif
	ComputedMap(i,j) = EcoMap(m,n)

    endfor
endfor

; Return the created ecosystem Map:
return, ComputedMap

end
