function createecomap, lat, lon, EcoFileName

;*************************************************************************
; Name: createecomap
;
; Purpose:
;   createEcoMap.pro creates the global ecosystem map which matches a given resolution. 
;   This map is generated by defining the resolution, creating the lat/lon array, and
;   then finding the nearest neighbor from the ecosystem ancillary file, 
;   for each geolocated point.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;    lat                Float Array: Latitude array
;    lon                Float Array: Longitude array
;    EcoFileName        String     : Full path and name of the ecosystem ancillary file
;
; Outputs:
;    ComputedMap        Byte Array : The ecosystem map that matches the geolocation for
;                                       the granule.
;
; Required Programs:
;  Read_Product_sds.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;Read in the Lat and Lons and Eco Map:
EcoFileID = HDF_SD_START(EcoFileName,/READ)
EcoLat = ReadSDS(EcoFileID,'Latitude', /scaleNo,/offsetNo,/fillNo)
EcoLon = ReadSDS(EcoFileID,'Longitude',/scaleNo,/offsetNo,/fillNo)
EcoMap = ReadSDS(EcoFileID,'SceneMap', /scaleNo,/offsetNo,/fillNo)
HDF_SD_END, EcoFileID
EcoXDim = 21600
EcoYDim = 10800

help, EcoLat
help, EcoLon
help, EcoMap

print, size(ecolat,/dimensions)
print, size(lat,/dimensions)

;Determine the size of the surface map to be generated:
dims = size(lon,/dimensions)
xdim = dims(0)
ydim = dims(1)
print, 'x,y',xdim,ydim

ComputedMap = bytarr(xdim,ydim)
help, ComputedMap

;print, 'EcoLon, EcoLat (1)',EcoLon(1),EcoLat(1)
;find the closest IGBP grid point:
gridResolution = 1.0 / 60.0
for j = 0, ydim-1 do begin
    for i = 0, xdim-1 do begin

	m = fix((lon(i,j) - EcoLon(1)) / gridResolution) + 1
	n = fix((lat(i,j) - EcoLat(1)) / gridResolution) + 1
	if (m gt EcoXDim) then m = EcoXDim - 1
	if (n gt EcoYDim) then n = EcoYDim - 1
        if (lon(i,j) lt -180.0) then m = 0
        if (lat(i,j) lt  -90.0) then n = 0

	ComputedMap(i,j) = EcoMap(m,n)

        if (lon(i,j) lt -180.0) then ComputedMap(i,j) = 0
        if (lat(i,j) lt  -90.0) then ComputedMap(i,j) = 0

    endfor
endfor

; Return the created ecosystem Map:
return, ComputedMap

end
