PRO irphaseplot

;*************************************************************************
; Name: irphaseplot
;
; Purpose:
;   This rountine is the main driver to plot the granule level IR Phase field.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's bit fields, generated in
;    the bit extraction routine, and produces the bit filed images.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the albedo map stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_bit_fields.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
; Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names. 
;*************************************************************************
;Define the text strings to use:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the files that contain the bit fields.
;*************************************************************************
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filenames   = StrArr(1)
filenames[0] = temp_HDF_path+'IRPhaseflags.'+Year+'.'+Day+'.'+Time+'.hdf'


;*************************************************************************
; Define the text string that will appear after the sds name.
;  Ex. The products will be named sdsname.textstring.ps
;      So one use would be to have the year.day.hourminute
;      outtextstring = '2000.110.0855'
;*************************************************************************
outtextstring = '.'+Year+'.'+Day+'.'+Time


;*************************************************************************
; Define the text string that will appear in the plot title, after the sds name.
;  Ex. The Title will be 'sdsname, textstring'
;      So one use would be to have the year.day.hourminute
;      plottextstring = 'Year 2000, Julian Day 110, 08:55'
;*************************************************************************
plottextstring = ', Day '+Day+', '+Year+' '+Time+'UTC.'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   of the granule(s) to plot.  The format is as follows:
;   	limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please comment this 
;   definition out.
;*************************************************************************
;limits=[-10.,110.,-40.,160.]; Australia
;limits=[-43.0,4.0,-4.0,36.0]


;*************************************************************************
; Define which SDS you would like to produce a plot of. 
; 1 means yes, 0 means no.
;*************************************************************************
;Define the number of SDS:
numSDS = 1
plot_sds    = intarr(numSDS)
plot_sds[ 0] = 1  ;IR_Phase 


;*************************************************************************
;*************************************************************************
; End of Definition section, Edit the lines below at your own risk.
;*************************************************************************
;*************************************************************************



;*************************************************************************
;Define the sds_name to be plotted.
;*************************************************************************
sds_name_arr = strarr(numSDS)
sds_name_arr[ 0] = 'IR_Phase'



;*************************************************************************
;Define the red, green, blue colors to use for the color bar.
;  Ex.  If the parameter is a yes, no, define the yes as green and 
;       the no as red, as follows:
;       values -> 0 = no, 1 = yes
;       rplot = [255,  0]
;       gplot = [  0,255]
;       bplot = [  0,  0] 
;*************************************************************************
;Initialize the arrays:
rplot_arr = intarr(6,numSDS)
gplot_arr = intarr(6,numSDS)
bplot_arr = intarr(6,numSDS)
;Define the colors for Cloud Phase Retr Proc Path:
; 0 = Clear Sky  (Grey ), 1 = Cloud, Water (Blue),
;2 = Cloud, Ice (White), 3 = Cloud, Mixed (Red ),
; 4 = Cloud, Uncertain  (Green),
rplot_arr[*, 0] = [150,  0,255,255,  0,  0]
gplot_arr[*, 0] = [150,  0,255,  0,255,  0]
bplot_arr[*, 0] = [150,255,255,  0,  0,  0]


;*************************************************************************
; Loop over all the sds and plot if sds_plot = 1:
;*************************************************************************
FOR icnt = 0, numSDS-1 DO BEGIN


   ;*************************************************************************
   ;Load the appropriate sds_name and color scheme:
   ;*************************************************************************
   sds_name = sds_name_arr[icnt]
   rplot    = rplot_arr [*,icnt]
   gplot    = gplot_arr [*,icnt]
   bplot    = bplot_arr [*,icnt]


   ;*************************************************************************
   ; Provide the name and path of the output image file, for example:
   ;	OutFileName = 'GlobalEcosystemMap.3600X1800.ps'
   ;*************************************************************************
   OutFileName = output_dir+sds_name+outtextstring+'.ps'


   ;*************************************************************************
   ;Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = sds_name+' '+plottextstring


   ;*************************************************************************
   ;Call the program, bearing in mind that only the postscript output is 
   ; available.  The basic call is as follows:
   ;*************************************************************************
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (plot_sds[icnt] eq 1) THEN BEGIN
      print, 'Plotting ',sds_name
      plot_bit_fields, filenames, sds_name, OutFileName, $
                       rplot, gplot, bplot, titlestring, /ps, /notation
   ENDIF ELSE BEGIN
      print, 'Skipping ',sds_name
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
ENDFOR

;*************************************************************************
;End the script:
;*************************************************************************

END
