function clm_bitextracter, MODFileName, ClMaskSDSName

;*************************************************************************
; Name: clm_bitextracter
;
; Purpose:
; ClM_BitExtracter.pro extracts the individual cloud mask tests from the full byte
;   cloud mask and places the results into an output array.
;
; Input: 
;    MODFileName        String     : Full path and name of the ecosystem ancillary file
;    ClMaskSDSName      String     : Name of the Cloud Mask SDS.
; 
; Output:
;    CloudMaskTests     Byte Array : The individual results of the cloud mask test,
;                                    written as follows:
;                                       CloudMaskTest(*,*,0:9)
;                                       CloudMaskTest(*,*,0) = Determined or not
;                                       CloudMaskTest(*,*,1) = Percent Cloudy Test
;                                       CloudMaskTest(*,*,2) = Day/Night Flag
;                                       CloudMaskTest(*,*,3) = Sun Glint Flag
;                                       CloudMaskTest(*,*,4) = Snow/Ice Flag
;                                       CloudMaskTest(*,*,5) = Surface Type
;                                       CloudMaskTest(*,*,6) = Heavy Aerosol 
;                                       CloudMaskTest(*,*,7) = Thin Cirrus Det (Vis) 
;                                       CloudMaskTest(*,*,8) = Shadow Found
;                                       CloudMaskTest(*,*,9) = Elevated Aerosol
;
; Required Programs:
;  Read_Product_sds.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************
;


;Read in the Cloud Mask, 1km:
print, MODFileName
print, ClMaskSDSName
MODFileID = HDF_SD_START(MODFileName,/READ)
CloudMask = ReadSDS(MODFileID,ClMaskSDSName,/scaleNo,/offsetNo,/fillNo)
HDF_SD_END, MODFileID
help, CloudMask

;Transpose the array from band,x,y to x,y,band:
CloudMask = TRANSPOSE(CloudMask, [1, 2, 0])
help, CloudMask

;Determine the size of the Cloud Mask array:
dims = size(CloudMask,/dimensions)
   xdim = dims(0)
   ydim = dims(1)
print, 'x,y',xdim,ydim

;Create the integer CloudMaskTests output array:
CloudMaskTests = IntArr(xdim,ydim,9)


;Extract the determined, or not test:
CloudMaskTests[*,*,0] =       (cloudMask[*,*,0] AND   1B)


;Extract the Cloudy Test:
CloudMaskTests[*,*,1] = ISHFT((cloudMask[*,*,0] AND   6B), -1)


;Extract the Day/Night Flag:
CloudMaskTests[*,*,2] = ISHFT((cloudMask[*,*,0] AND   8B), -3)


;Extract the Sun Glint Flag:
CloudMaskTests[*,*,3] = ISHFT((cloudMask[*,*,0] AND  16B), -4)


;Extract the Snow/Ice Flag:
CloudMaskTests[*,*,4] = ISHFT((cloudMask[*,*,0] AND  32B), -5)


;Extract the Surface Type:
CloudMaskTests[*,*,5] = ISHFT((cloudMask[*,*,0] AND 192B), -6)


;Extract the Heavy Aerosol Detection:
CloudMaskTests[*,*,6] =       (cloudMask[*,*,1] AND   1B)


;Extract the Thin Cirrus Detection (Visible):
CloudMaskTests[*,*,7] = ISHFT((cloudMask[*,*,1] AND   2B), -1)


;Extract the Shadow Found Flag:
CloudMaskTests[*,*,8] = ISHFT((cloudMask[*,*,1] AND   4B), -2)


;Convert the Int array into a byte array:
CloudMaskTests = BYTE(CloudMaskTests)


; Return the Extracted Cloud Mask Tests:
return, CloudMaskTests

end
