function ir_bitextracter, MOD06FileName

;*************************************************************************
; Name: ir_bitextracter
;
; Purpose:
; IR_BitExtracter.pro extracts the individual QA flags from the full byte
;   array 1km QA and places the results into an output array.
;
; Input: 
;    MOD06FileName      String     : Full path and name of the ecosystem ancillary file
; 
; Output:
;    QABitFlags         Byte Array  : The individual results of the QA flags,
;                                    written as follows:
;                       L2QAFlags(*,*,0:1)
;                       L2QAFlags(*,*, 0) = IR Phase 
;
; Required Programs:
;  Read_Product_sds.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************
;


;Read in the QA, 1km:
MOD06FileID = HDF_SD_START(MOD06FileName,/READ)
L2QA = ReadSDS(MOD06FileID,'Cloud_Phase_Infrared',/scaleNo,/offsetNo,/fillNo)
HDF_SD_END, MOD06FileID


;Determine the size of the Cloud Mask array:
dims = size(L2QA,/dimensions)
xdim = dims(0)
ydim = dims(1)
print, 'x,y dims',xdim,ydim


;Create the integer L2QAFlags output array:
L2QAFlags = IntArr(xdim,ydim,20)


rp_pts = where((L2QA lt 0),num_rp)
print,'Number of negss',num_rp
rp_pts = where((L2QA eq 0),num_rp)
print,'Number of 0s',num_rp
rp_pts = where((L2QA eq 1),num_rp)
print,'Number of 1s',num_rp
rp_pts = where((L2QA eq 2),num_rp)
print,'Number of 2s',num_rp
rp_pts = where((L2QA eq 3),num_rp)
print,'Number of 3s',num_rp
rp_pts = where((L2QA eq 4),num_rp)
print,'Number of 4s',num_rp
rp_pts = where((L2QA eq 5),num_rp)
print,'Number of 5s',num_rp
rp_pts = where((L2QA eq 6),num_rp)
print,'Number of 6s',num_rp
rp_pts = where((L2QA gt 6),num_rp)
print,'Number > 6',num_rp


;Replace all values of 5 with 1, since both are water:
rp_pts = where((L2QA eq 5),num_rp)
print, 'Addition Water Points', num_rp
if num_rp gt 0 then L2QA(rp_pts) = 1 
rp_pts = where((L2QA eq 1),num_rp)
print, 'Total Water Points', num_rp



;Replace all values of 4 with 2, since both are ice:
rp_pts = where((L2QA eq 4),num_rp)
print, 'Addition Ice Points', num_rp
if num_rp gt 0 then L2QA(rp_pts) = 2 
rp_pts = where((L2QA eq 2),num_rp)
print, 'Total Ice Points', num_rp



;Replace all values of 6 with 4, to lend order:
rp_pts = where((L2QA eq 6),num_rp)
print, 'Uncertain Points', num_rp
if num_rp gt 0 then L2QA(rp_pts) = 4
rp_pts = where((L2QA eq 4),num_rp)
print, 'Total Uncertain Points', num_rp




;IR Phase:
L2QAFlags[*,*, 0] =  L2QA[*,*] 


; Return the Extracted L2 QA Flags:
return, L2QAFlags

end
