#!/usr/local/bin/perl -w

#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
# Name: Mapped.pl
#
# Purpose:
# This script will run the MODIS Atmosphere granule level mapped visualization codes
# and convert the output tiff images to jpgs, if desired.
#
# Modification history:
#  11/08/2001
#    Initial Release.
#
# Credits:
#  Written by Eric G. Moody
#  eric.moody@gsfc.nasa.gov
#  Climate and Radiation Branch
#  NASA Goddard Space Flight Center
#  Greenbelt, Maryland, U.S.A.
#
# License:
# This software is provided "as-is", without any express or
# implied warranty. In no event will the authors be held liable
# for any damages arising from the use of this software.
#
# Permission is granted to anyone to use this software and to alter
# it freely, subject to the following restrictions:
#
# 1. The origin of this software must not be misrepresented; you must
#    not claim you wrote the original software. If you use this software
#    in a product, an acknowledgment in the product documentation
#    would be appreciated, but is not required.
#
# 2. Altered source versions must be plainly marked as such, and must
#    not be misrepresented as being the original software.
#
# 3. This notice may not be removed or altered from any source distribution.
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------

#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
# This script will run the MODIS Atmosphere granule level mapped visualization codes
# and convert the output tiff images to jpgs, if desired.
#
# The following are a brief list of images that can be produced.  Bear in mind that these 
#  codes can be modified to produce other images, but these specific variables are of 
#  interest to the code designer.  These codes produce single granule level images.
#   Albedo     - Granule level albedo plots at varying wavelengths, as used in MOD06OD.
#   Ancillary  - Ancillary data used in MOD06OD.  Only available with local production of OD.
#   Cloud Mask - Selected bit fields from the MOD35 cloud mask.
#   Ecosystem  - Granule level IGBP ecosystem classification.
#   L1B        - Level 1B True color RGB composite image.
#   L2         - Select MOD06 Level 2 parameters.
#   Phase      - Cloud Optical Thickness and Effective Radius plots with phase 
#                  discrimination through seperate phase color schemes.
#   QA_L2      - Selected bit fields from the MOD06 Quality Assurance.
#
# These codes plot individual granules, but this script allows a series of granules to
#  be processed in the User Definition section immeadiately following this note.  In addition,
#  there are several options and director paths that can be modified.  
#
#  The directory structures to define include:
#  1) Base paths for where the data is stored.  For our purposes, we have MODIS data stored
#      in several ways.  Most data is stored as /ingest/MODXX/Year/Day/ with all of the day's
#      granules stored in the Day subdirectory.  Some times the data is stored for reprocessing
#      efforts, so that the data is stored in inputs and outputs, and other times all the hdf files
#      for a single granule are stored in a single directory.  To provide for various scenarios,
#      the user defines the base path for the L1B, MOD03, 06,35, and ancillary files.  Then there
#      is a flag (base_eq_full_path) for the third scenario (all files in 1 directory), and a flag
#      for switching between scenarios 1 and 2, which covers how. the year and day/time info is tacked on.
#  2) Base path for storing the images (Base_img_out_Path).  The images will be stored in the base
#      path plus Unmapped.Year.Day.Time.  This way you can have a directory of images separate from
#      the code directories.
#  3) Location of the IGBP Ecosystem Map (IGBP_map_path).  This is used for Ecosystem mapping.
#  4) Path where temporary HDF files will be stored.  The Bit mapping, Ecosystem, and Albedo codes
#      create temporary HDF files, which you have the option of saving or deleting.  This path
#      defines where those temp files are to be (temporarily) stored.
#
#  The options include:
#  1) Flags to exclude certain codes from running.  For example if you only want to plot the
#       ecosystem, you can adjust the flags to run just the ecosystem plotting code.
#  2) A flag to delete all of the temperary HDF files generated by the vis codes.  For example,
#       the bit field codes generate an HDF file that contains individual fields, stored as 
#       separate HDF SDSs.  If you care to store these HDF files, you can set this flag.
#  3) Two flags can be set to control jpg production.  The vis codes produce tiff images,
#       but a flag (jpg_convert) can be set to convert the tiffs to jpgs, and store the jpgs
#       in a different directory.  There is a separate flag (jpg_only) which can be set in 
#       case you had the jpg_convert turned off, but later want to create the jpgs.  This 
#       will just convert the tiffs without having to run the vis codes.
#  4) There are two flags to define where the L1B and L2 files are stored, as explained in
#       part 1 of the directory structure section directly above.  If all the files for one
#       granule are stored in one directory, set the Base paths to point to that directory
#       and set the $Base_eq_Full_path flag to 1.  The other flag, moody_processing_flag
#       controls the date structure tacked onto the base path.  if the flag is set to 1,
#       then the date structure will reflect our MOD06/35 local reprocessing structure which
#       looks like /atmos/m/Processing/inputs/inputs-YYYY.DDD.HHMM, so set the base path to
#       /atmos/m/Processing/inputs/inputs- and set this flag to 1.
#       If the flag is set to 0, then it is assumed that the data structure is set up like
#       /ingest/MODXX/YYYY/DDD/, where all the granules for 1 day's MOD are stored in the
#       day, DDD, subdirectory.  So, set the base path to /ingest/MODXX/ and the YYYY/DDD 
#       is then tacked on.
#
#  Options inside the vis codes.
#   Inside each visualization code, there is a driver in which other options, such as
#    which products to plot, plotting limits, title and output names can be modified.
#
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------


#--------------------------------------------------------
#--------------------------------------------------------
# User Definition section.
#--------------------------------------------------------
#--------------------------------------------------------

#------------------------------------------------------
#Define the year, day, and time of the granule:  These are
# arrays, so you can run multiple granlues.
#------------------------------------------------------
$num_grans = 1;
@year_arr = ( '2000', '2001', '2001', '2001' );
@day_arr  = ( '265',  '079',  '097' , '009'  );
@time_arr = ( '0835', '0255', '0240', '0655' );

#------------------------------------------------------
# There are eight codes that can be run, define yes/no (1/0)
# which ones are to be run.  The codes are Albedo, Ancillary
# Ecosystem, Cloud Mask, L2QA, L2, L1B, EPRD, IRphase, Re and COT Phase:
#------------------------------------------------------
$plot_Alb    = 1; #Albedo
$plot_Anc    = 1; #Ancillary
$plot_Eco    = 1; #Ecosystem
$plot_CM     = 1; #Cloud Mask
$plot_L2QA   = 1; #L2QA 
$plot_L2     = 1; #L2
$plot_L1B    = 1; #L1B
$plot_EPRD   = 1; #EPRD
$plot_IRP    = 1; #IR Phase
$plot_Phs    = 1; #Re, COT, ReD Phase plots

#------------------------------------------------------
# Define the Base file paths for L1B, MOD03, 06, 35, & Ancillary. 
#  Do not include /year/day/time, as this will be added
#  when the code looks through the granules.
#------------------------------------------------------
$Base_L1B_Path   = "/atmos/moody/Processing/inputs/inputs-";
$Base_MOD03_Path = "/atmos/moody/Processing/inputs/inputs-";
$Base_MOD06_Path = "/atmos/moody/Processing/outputs/outputs-";
$Base_MOD35_Path = "/atmos/moody/Processing/outputs/outputs-";
$Base_Anc_Path   = "/atmos/moody/Processing/outputs/outputs-";

#Example when using ./YYYY/DDD/ structure, then
# set moody_processing_flag to 0.
#$Base_L1B_Path   = "/ingest/MOD021KM/";
#$Base_MOD03_Path = "/ingest/MOD03/";
#$Base_MOD06_Path = "/ingest/MOD06/";
#$Base_MOD35_Path = "/ingest/MOD35/";
#$Base_Anc_Path   = "/ingest/MOD03/";

#------------------------------------------------------
# Define the Base file paths for the image output directory:
#  Do not include /year/day/time, as this will be added
#  when the code looks through the granules.
#------------------------------------------------------
$Base_img_out_Path = "/atmos/.../Mapped_Vis/images/Mapped/";

#------------------------------------------------------
# Define the full path to the IGBP ecosystem map:
#------------------------------------------------------
$IGBP_map_path = "/atmos/.../Mapped_Vis/IGBP_map/";

#------------------------------------------------------
# Define the full path where the temporary hdf files
#  will be placed.  These hdf files are generated by
#  the bit extraction codes, Ecosystem and albedo codes.
#------------------------------------------------------
$temp_HDF_path = "/atmos/.../Mapped_Vis/temp_HDF_files/Mapped/";

#------------------------------------------------------
# Flag yes/no, 1/0, to delete the temporary hdf files after run:
#------------------------------------------------------
$del_temp_HDF = 1;

#------------------------------------------------------
# Flag yes/no, 1/0, if this is moody's reprocessing directory
#  structure.  If yes, then it is pathYYYY.DDD.HHMM  
#  Otherwise it is assumed that the directory structure is
#  set up as path/YYYY/DDD/. 
#------------------------------------------------------
$moody_processing_flag = 1;

#------------------------------------------------------
# If there is nothing to be added to the Base Path,
# set this flag to 1. For example, if all the files
# are stored in one directory, set the Base Path and
# then this to 0.
#------------------------------------------------------
$Base_eq_Full_path = 0;

#------------------------------------------------------
# Should you produce the jpgs? (1/0, yes/no):
#------------------------------------------------------
$jpg_convert = 1; 

#------------------------------------------------------
# Do you want to just produce the jpgs (1/0, yes/no):
#------------------------------------------------------
$jpg_only = 0;



#--------------------------------------------------------
#--------------------------------------------------------
# Define the directory structure:
#--------------------------------------------------------
#--------------------------------------------------------

#--------------------------------------------------------
# Loop over the granules:
#--------------------------------------------------------
for ($gran_cnt = 0; $gran_cnt<=$num_grans-1; $gran_cnt++) {

  #--------------------------------------------------------
  # Read in the granule's year, day, and time:
  #--------------------------------------------------------
  $year = $year_arr[$gran_cnt];
  $day  = $day_arr [$gran_cnt];
  $time = $time_arr[$gran_cnt];
  
  print "\n\n\n\nProcessing Day $day, $year $time UTC.\n";

  #------------------------------------------------------
  #Define the main directory to process & change to it:
  #------------------------------------------------------
  $MainPath = $ENV{"PWD"};
  chdir ("$MainPath");
  
  #------------------------------------------------------
  # Define the directories containing L1B and L2 input/outputs:
  #------------------------------------------------------
  #------------------------------------------------------
  # Define the full path with date and time(?):
  #------------------------------------------------------
  if ($moody_processing_flag == 1) {
    # thus the structure is pathYYYY.DDD.HHMM:
    $Full_L1B_Path   = "$Base_L1B_Path$year.$day.$time/";
    $Full_MOD03_Path = "$Base_MOD03_Path$year.$day.$time/";
    $Full_MOD06_Path = "$Base_MOD06_Path$year.$day.$time/";
    $Full_MOD35_Path = "$Base_MOD35_Path$year.$day.$time/";
    $Full_Anc_Path   = "$Base_Anc_Path$year.$day.$time/";
  } else {
    #Structure assumed pathYYYY/DDD:
    $Full_L1B_Path   = "$Base_L1B_Path$year/$day/";
    $Full_MOD03_Path = "$Base_MOD03_Path$year/$day/";
    $Full_MOD06_Path = "$Base_MOD06_Path$year/$day/";
    $Full_MOD35_Path = "$Base_MOD35_Path$year/$day/";
  }
  if ($Base_eq_Full_path == 1) {
    $Full_L1B_Path   = "$Base_L1B_Path";
    $Full_MOD03_Path = "$Base_MOD03_Path";
    $Full_MOD06_Path = "$Base_MOD06_Path";
    $Full_MOD35_Path = "$Base_MOD35_Path";
    $Full_Anc_Path   = "$Base_Anc_Path";
  }  
 
 
  #------------------------------------------------------
  # Define the paths where the codes reside:
  #------------------------------------------------------
  #Ancillary codes:
  $Alb_code_path = "$MainPath/Ancillary/Albedo/";
  $Anc_code_path = "$MainPath/Ancillary/AncillaryMapper/";
  $Eco_code_path = "$MainPath/Ancillary/Ecosystem/";
  #The three bit extraction codes and the plotting code:
  $CM_ext_code_path    = "$MainPath/BitExtraction/CloudMaskExtracter/";
  $L2QA_ext_code_path  = "$MainPath/BitExtraction/L2QA_Extracter/";
  $IRP_ext_code_path   = "$MainPath/BitExtraction/IRPhase_Extracter/";
  $Bit_map_code_path   = "$MainPath/BitExtraction/BitMapper/";
  #Products codes:
  $L2_code_path   = "$MainPath/Products/l2/";
  $L1B_code_path  = "$MainPath/Products/l1b/";
  $EPRD_code_path = "$MainPath/Products/eprd_plotter/";
  $Phs_code_path  = "$MainPath/Products/phase_plotter/";
  
  #------------------------------------------------------
  # Define the overall output paths, overall, jpg, and ps:
  #------------------------------------------------------
  $output_path = "$Base_img_out_Path/Mapped.$year.$day.$time/";
  $jpg_path    = "$output_path"."jpg.$year.$day.$time/";
  $ps_path     = "$output_path"."ps.$year.$day.$time/";
  system "mkdir $output_path $jpg_path $ps_path";
  
  #------------------------------------------------------
  #Define the 8 ps file paths:
  #------------------------------------------------------
  $ps_Alb_path   = "$ps_path/Alb.$year.$day.$time/";
  $ps_Anc_path   = "$ps_path/Anc.$year.$day.$time/";
  $ps_Eco_path   = "$ps_path/Eco.$year.$day.$time/";
  $ps_CM_path    = "$ps_path/Cld_Msk.$year.$day.$time/";
  $ps_L2QA_path  = "$ps_path/QA_L2.$year.$day.$time/";
  $ps_L2_path    = "$ps_path/L2.$year.$day.$time/";
  $ps_Phase_path = "$ps_path/Phase.$year.$day.$time/";
  
  #------------------------------------------------------
  #Define the 8 jpg file paths:
  #------------------------------------------------------
  $jpg_Alb_path   = "$jpg_path/Alb.$year.$day.$time/";
  $jpg_Anc_path   = "$jpg_path/Anc.$year.$day.$time/";
  $jpg_Eco_path   = "$jpg_path/Eco.$year.$day.$time/";
  $jpg_CM_path    = "$jpg_path/Cld_Msk.$year.$day.$time/";
  $jpg_L2QA_path  = "$jpg_path/QA_L2.$year.$day.$time/";
  $jpg_L2_path    = "$jpg_path/L2.$year.$day.$time/";
  $jpg_L1B_path   = "$jpg_path/L1B.$year.$day.$time/";
  $jpg_Phase_path = "$jpg_path/Phase.$year.$day.$time/";
  
  
  #--------------------------------------------------------
  #--------------------------------------------------------
  # Run the visualization codes:
  #--------------------------------------------------------
  #--------------------------------------------------------

  #--------------------------------------------------------
  #Check to see if you only want to run the jpgs:
  #--------------------------------------------------------
  if ($jpg_only == 0) {

  #--------------------------------------------------------
  # Set common environmental variables:
  #--------------------------------------------------------
  # Set the year, day, time:
  $ENV{"Year"} = $year;
  $ENV{"Day"}  = $day;
  $ENV{"Time"} = $time;
  # Set the path to the ecosystem map and temp hdf file storage:
  $ENV{"IGBP_map_path"} = $IGBP_map_path;
  $ENV{"temp_HDF_path"} = $temp_HDF_path;
 
  
  #--------------------------------------------------------
  # Albedo code:
  # This consists of two codes, the Albedo generator, and mapper:
  #--------------------------------------------------------
  if ($plot_Alb == 1) {
    print "Plotting Albedo.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_Alb_path $jpg_Alb_path";
    
    #Run the Albedo generator:
    #First set up the environmental variables to be passed:
    $ENV{"Input_Path"} = $Full_MOD03_Path;
    #Change to the code directory:
    chdir ("$Alb_code_path/GranuleAlbedoMap");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "alb_map_driver\n";
    close(WRITEME);
    
    #Run the Albedo plotter:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"} = $ps_Alb_path;
    #Change to the code directory:
    chdir ("$Alb_code_path/Albedo_plotter");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "alb\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # Ancillary mapper:
  #--------------------------------------------------------
  if ($plot_Anc == 1) {
    print "Plotting Ancillary.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_Anc_path $jpg_Anc_path";
    
    #Run the Ancillary Mapper:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"}  = $ps_Anc_path; 
    $ENV{"Input_Path"}   = $Full_Anc_Path;
    $ENV{"Input_Path_2"} = $Full_MOD03_Path;
    #Change to the code directory:
    chdir ("$Anc_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "anci\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # Ecosystem code:
  # This consists of two codes, the Ecosystem generator, and mapper:
  #--------------------------------------------------------
  if ($plot_Eco == 1) {
    print "Plotting Ecosystem.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_Eco_path $jpg_Eco_path";
    
    #Run the Ecosystem generator:
    #First set up the environmental variables to be passed:
    $ENV{"Input_Path"} = $Full_MOD03_Path;
    #Change to the code directory:
    chdir ("$Eco_code_path/EcosystemMap");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "eco_map_driver\n";
    close(WRITEME);
    
    #Run the Ecosystem plotter:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"} = $ps_Eco_path;
    #Change to the code directory:
    chdir ("$Eco_code_path/EcosystemMapper");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "eco\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # Cloud Mask:
  #--------------------------------------------------------
  if ($plot_CM == 1) {
    print "Plotting Cloud Mask.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_CM_path $jpg_CM_path";
    
    #Run the Cloud Mask Bit Extracter:
    #First set up the environmental variables to be passed:
    $ENV{"Input_Path"} = $Full_MOD35_Path;
    #Change to the code directory:
    chdir ("$CM_ext_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "clm_ext_driver\n";
    close(WRITEME);
    
    #Run the Cloud Mask plotter:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"} = $ps_CM_path;
    #Change to the code directory:
    chdir ("$Bit_map_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "cloudplot\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # L2 QA:
  #--------------------------------------------------------
  if ($plot_L2QA == 1) {
    print "Plotting L2QA.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_L2QA_path $jpg_L2QA_path";
    
    #Run the L2QA Bit Extracter:
    #First set up the environmental variables to be passed:
    $ENV{"Input_Path"} = $Full_MOD06_Path;
    #Change to the code directory:
    chdir ("$L2QA_ext_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "l2qa_ext_driver\n";
    close(WRITEME);
    
    #Run the L2QA plotter:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"} = $ps_L2QA_path;
    #Change to the code directory:
    chdir ("$Bit_map_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "l2qaplot\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # L2:
  #--------------------------------------------------------
  if ($plot_L2 == 1) {
    print "Plotting L2.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_L2_path $jpg_L2_path";
    
    #Run the L2 Mapper:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"}  = $ps_L2_path; 
    $ENV{"Input_Path"}   = $Full_MOD06_Path;
    #Change to the code directory:
    chdir ("$L2_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "mod06\n";
    close(WRITEME);
  }
  
  
  
  #--------------------------------------------------------
  # L1B:
  #--------------------------------------------------------
  if ($plot_L1B == 1) {
    print "Plotting L1B.\n";
    #Create the output jpg directory:
    system "mkdir $jpg_L1B_path";
    
    #Run the L1B visualizer:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"}  = $jpg_L1B_path;
    
    #Determine the L1B file to be processed:
    #Change to the input directory:
    chdir ("$Full_L1B_Path");
    #Find the file and place the name in a holder:
    $file_spec = "MOD021KM.A$year$day.$time*.hdf";
    @l1b_files = glob("$file_spec");
    
    #Change to the code directory:
    chdir ("$L1B_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME ".r viewimg.pro\n";
    print WRITEME "3\n";
    print WRITEME "$Full_L1B_Path\n";
    print WRITEME "$l1b_files[0]\n";
    print WRITEME "3\n";
    print WRITEME "1\n";
    print WRITEME "1 4 3\n";
    print WRITEME "2\n";
    close(WRITEME);
  }
  
  
  #--------------------------------------------------------
  # EPRD:
  #--------------------------------------------------------
  if ($plot_EPRD == 1) {
    print "Plotting EPRD.\n";
    #Create the output ps and jpg directories:
    # Note: Since the EPRD is part of L2 output,
    #   the output path is the L2 path.
    system "mkdir $ps_L2_path $jpg_L2_path";
    
    #Run the EPRD Mapper:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"}  = $ps_L2_path; 
    $ENV{"Input_Path"}   = $Full_MOD06_Path;
    #Change to the code directory:
    chdir ("$EPRD_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "eprd\n";
    close(WRITEME);
  }


  #--------------------------------------------------------
  # IR Phase Extractor - part of L2 QA, thus stored in L2QA output dir:
  #--------------------------------------------------------
  if ($plot_IRP == 1) {
    print "Plotting IR Phase.\n";
    #Create the output ps and jpg directories:
    system "mkdir $ps_L2QA_path $jpg_L2QA_path";
    
    #Run the IR Phase Bit Extracter:
    #First set up the environmental variables to be passed:
    $ENV{"Input_Path"} = $Full_MOD06_Path;
    #Change to the code directory:
    chdir ("$IRP_ext_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "IR_ext_driver\n";
    close(WRITEME);
    
    #Run the IR Phase QA plotter:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"} = $ps_L2QA_path;
    #Change to the code directory:
    chdir ("$Bit_map_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "irphaseplot\n";
    close(WRITEME);
  }

  #--------------------------------------------------------
  # COT, Re, ReD phase plots:
  #--------------------------------------------------------
  if ($plot_Phs == 1) {
    print "Plotting log scale Phase plots.\n";
    #Create the output ps and jpg directory:
    system "mkdir $ps_Phase_path $jpg_Phase_path";
    
    #Run the log scale Phase Mapper:
    #First set up the environmental variables to be passed:
    $ENV{"Output_Path"}  = $ps_Phase_path; 
    $ENV{"Input_Path"}   = $Full_MOD06_Path;
    #Change to the code directory:
    chdir ("$Phs_code_path");
    #Run the code:
    $pid = open(WRITEME, "|idl -quiet") or die "Couldn'tfork: $!\n";
    print WRITEME "phase\n";
    close(WRITEME);
  }
  
  
 
  #------------------------------------------------------
  # Delete the temporary hdf files, if desired:
  #------------------------------------------------------
  if ($del_temp_HDF == 1) {
    print "\nDeleting temporary HDF files.\n";
    chdir ("$temp_HDF_path");
    system("rm -f *.$year.$day.$time.hdf");
  }


  #--------------------------------------------------------
  # End the check to see if you only want to produce jpgs:
  #--------------------------------------------------------
  }
   
  
  
  #------------------------------------------------------
  #Loop through the directories, converting
  # them to jpegs, and storing the jpgs in the jpgs directory.
  # Note that the L1B is already a jpg, so no conversion
  #------------------------------------------------------
  if ($jpg_convert == 1) {
  print "\nConverting from .ps to .jpg.\n";
  for ($dir_cnt = 0; $dir_cnt<=6; $dir_cnt++) {
    
    #------------------------------------------------------
    #Change to the directory
    #------------------------------------------------------
    if ($dir_cnt == 0) {
      chdir ("$ps_Alb_path");
      $convert = $plot_Alb;
    } elsif ($dir_cnt == 1) {
      chdir ("$ps_Anc_path");
      $convert = $plot_Anc;
    } elsif ($dir_cnt == 2) {
      chdir ("$ps_Eco_path");
      $convert = $plot_Eco;
    } elsif ($dir_cnt == 3) {
      chdir ("$ps_CM_path");
      $convert = $plot_CM;
    } elsif ($dir_cnt == 4) {
      chdir ("$ps_L2QA_path");
      if ( ($plot_L2QA == 1) or ($plot_IRP == 1)) {$convert = 1;}
    } elsif ($dir_cnt == 5) {
      chdir ("$ps_Phase_path");
      $convert = $plot_Phs;
    } else {
      chdir ("$ps_L2_path");
      if ( ($plot_L2 == 1) or ($plot_EPRD == 1)) {$convert = 1;}
    }
    
    
    #------------------------------------------------------
    # Only process if the ps were produced:
    #------------------------------------------------------
    if ($convert == 1) {
      
      #------------------------------------------------------
      #Loop through the files in the directory, converting
      # them to jpegs
      #------------------------------------------------------
      foreach my $filename (<*.ps>) {
	
	#----------------------------------------------------
	#Create the JPEG:
	#----------------------------------------------------
	#Create the new filename, by chopping off the ps
	# and replacing it with .jpeg:
	$newfilename = $filename;
	for ($i = 0; $i<= 1; $i++) {
	  chop($newfilename);
	}
	$newending   = 'jpg';
	$newfilename = "$newfilename$newending";
	
	#Run the convert command:
	$runString = "convert -density 288 -quality 90 -geometry 65x65% -rotate -90 -crop 0x0";
	$namesString = "$filename $newfilename";
	$command = "$runString $namesString";
	system "$command";
	
      }
      
      #------------------------------------------------------
      #Mv the ps to the ps directory:
      #------------------------------------------------------
      if ($dir_cnt == 0) {
	system "mv *.jpg $jpg_Alb_path";
      } elsif ($dir_cnt == 1) {
	system "mv *.jpg $jpg_Anc_path";
      } elsif ($dir_cnt == 2) {
	system "mv *.jpg $jpg_Eco_path";
      } elsif ($dir_cnt == 3) {
	system "mv *.jpg $jpg_CM_path";
      } elsif ($dir_cnt == 4) {
	system "mv *.jpg $jpg_L2QA_path";
      } elsif ($dir_cnt == 5) {
        system "mv *.jpg $jpg_Phase_path";
      } else {
	system "mv *.jpg $jpg_L2_path";
      } 
      
      
      #End if produced.
    }
    
  #End the looping over output type. 
  }
  #End the if statement:
  }
  
  
#End looping over granules:
}
