pro read_product_sds,datavalue,allvalidrange, fillvalue, fileId, varname,fail,$
                  scaleNo=scaleNo, offsetNo=offsetNo, fillNo=fillNo
;+
;.......................................................................
; $Id$
;.......................................................................
; NAME: ReadSDS
;	
;
; PURPOSE:
;        given file id and a variable name, retrieve "calibrated" data 
;        values.
;	
;
; CATEGORY:
;        HDF data reader
;
;
; CALLING SEQUENCE:
;	Result = ReadSDS(fileId, varname)
;
; INPUTS:
;	fileId:	HDF file id number
;       varname: variable name
;
; OPTIONAL INPUTS:
;       scaleNo:  This parameter does not have scale factor attribute;
;                 default assumes that it has.
;       offsetNo: This parameter does not have offset attribute; 
;                 default assumes that it has.
;       fillNo:   This parameter does not have fill value attribute;
;                 default assumes that it has.
;
;
; OUTPUTS:
;       calibrated data in proper physical units
;
;
; USAGE EXAMPLES:
;
; fileId = HDF_SD_START("sample.hdf", /READ)
; variable = ReadSDS(fileId, 'Cloud_Mask')
; HDF_SD_END, fileId
;
; SIDE EFFECTS:
;       None.
;.......................................................................
; REVISION HISTORY:
;       3/7/00	MAG	Updates with proper MODIS names and additional
;                       code to take into account incorrectly set FillValues
;                       in the L-1B data itself. 
;.......................................................................
; PROGRAMMER:  
;              Mark A Gray (gray@climate.gsfc.nasa.gov
;	       Eric Moody
;              Jason Li 
;              SM&A Inc | Climate and Radiation Branch
;              NASA Goddard Space Flight Center
;              Greenbelt, Maryland, U.S.A.
;.......................................................................
;-

fail=0

;... read SDS data:

index = HDF_SD_NAMETOINDEX(fileId, varname)
sdsid = HDF_SD_SELECT(fileId, index)
HDF_SD_GETDATA, sdsid, dataValue
HDF_SD_ENDACCESS, sdsid


;... read attributes:

scale_sds_name= 'scale_factor'
IF NOT Keyword_Set(scaleNo) THEN BEGIN
   scaleId = HDF_SD_ATTRFIND(sdsid,scale_sds_name)
   IF scaleId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, scaleId, DATA=scale_factor
   ENDIF
ENDIF

offset_sds_name= 'add_offset'
IF NOT Keyword_Set(offsetNo) THEN BEGIN
   offsetId = HDF_SD_ATTRFIND(sdsid,offset_sds_name)
   IF offsetId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, offsetId, DATA=offset
   ENDIF
ENDIF

validrange_sds_name= 'valid_range'
IF NOT Keyword_Set(validrangeNo) THEN BEGIN
   validrangeId = HDF_SD_ATTRFIND(sdsid,validrange_sds_name)
   IF validrangeId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, validrangeId, DATA=validrange
   ENDIF
ENDIF

fillvalue_sds_name= '_FillValue'
IF NOT Keyword_Set(fillNo) THEN BEGIN
   fillId = HDF_SD_ATTRFIND(sdsid,fillvalue_sds_name)
   IF fillId NE -1 THEN BEGIN
      HDF_SD_ATTRINFO, sdsid, fillId, DATA=fillValue
   ENDIF
   fillvalue=fillvalue[0]
ENDIF

;... calibrate data by applying scale factor and offset if necessary:

datavalue=float(datavalue)
fillvalue=float(fillvalue)

arraysizetemp=size(dataValue)
if not keyword_set(scaleNo) then begin
case 1 of
   max(DataValue) eq -1 and min(DataValue) eq -1: begin
      ;data is a probably a vis channel viewed at nighttime 
      ;let's get the hell out here! eek!
      print,'Cannot find any useful data in the sds ',varname
      fail= 1
   end
   arraysizetemp(0) eq 2: begin
      allvalidrange=fltarr(2)
      dataValue[*,*]  = scale_factor[0] * (dataValue[*,*]-offset[0])
      allvalidrange[0:1]= scale_factor[0] * (validrange[0:1]-offset[0])
      fillvalue = scale_factor[0] * (fillvalue-offset[0])
   end
   arraysizetemp(0) eq 3: begin
      allvalidrange=fltarr(2,arraysizetemp[1])
      for band =0, arraysizetemp[1]-1 do begin
         allvalidrange[*,band]= scale_factor[0] * (validrange-offset[0])
         dataValue[band,*,*]  = scale_factor[0] * (dataValue[band,*,*]-offset[0])
      endfor
      fillvalue = scale_factor[0] * (fillvalue-offset[0])
   end
else:print,'Oh my, in big trouble here.  your crash is being served'


endcase
endif

allvalidrange = float(allvalidrange)
datavalue = float(datavalue)
fillvalue = float(fillvalue)


end
